extends Node

var screenWith : int = 2560
var screenHeight : int = 1080

var only_fullscreen : bool = false

var gravity : int = 700

var playerFaceColor = Color('#00ffff')
var time_score = 0
var time = 0
var pause : bool = false
var quiting : bool = false
var current_scene = null
var current_start_position = 0
var player_position : Vector2 = Vector2(0,0)

var beachFound : bool = false
var runCut1 : bool = true

var meadowFound : bool = false
var runCutMeadow : bool = true

var lakesFound : bool = false

var townFound : bool = false
var runCutTown : bool = true

var cityRoofFound : bool = false
var runCutCityRoof : bool = true


# Called when the node enters the scene tree for the first time.
func _ready():
	var root = get_tree().get_root()
	current_scene = root.get_child(root.get_child_count() - 1)
	
	if ((get_window().mode == Window.MODE_EXCLUSIVE_FULLSCREEN) or (get_window().mode == Window.MODE_FULLSCREEN)):
		only_fullscreen = true


# Called every frame. 'delta' is the elapsed time since the previous frame.
func _process(_delta):
	if Input.is_action_pressed("fullscreen") and !only_fullscreen:
		get_window().mode = Window.MODE_EXCLUSIVE_FULLSCREEN if (!((get_window().mode == Window.MODE_EXCLUSIVE_FULLSCREEN) or (get_window().mode == Window.MODE_FULLSCREEN))) else Window.MODE_WINDOWED

	if Input.is_action_pressed("menu"):
		goto_menu()
	
	if get_tree().current_scene.name != "mainMenu":
		time += _delta


func goto_menu():
	call_deferred(
		"_deferred_goto_scene",
		"res://levels/main_menu/MainMenu.tscn"
		)
	
func goto_scene(path):
	# This function will usually be called from a signal callback,
	# or some other function in the current scene.
	# Deleting the current scene at this point is
	# a bad idea, because it may still be executing code.
	# This will result in a crash or unexpected behavior.

	# The solution is to defer the load to a later time, when
	# we can be sure that no code from the current scene is running:
	call_deferred("_deferred_goto_scene", path)


func _deferred_goto_scene(path):
	# It is now safe to remove the current scene
	current_scene.free()
	# Load the new scene.
	var s = ResourceLoader.load(path)
	# Instance the new scene.
	current_scene = s.instantiate()
	# Add it to the active scene, as child of root.
	get_tree().get_root().add_child(current_scene)
	# Optionally, to make it compatible with the SceneTree.change_scene_to_file() API.
	get_tree().set_current_scene(current_scene)


func to_dictionary():
	return {
		"playerFaceColor" : playerFaceColor.to_html(false),
		"time_score" : time_score,
		"time" : time,
		"beachFound" : beachFound,
		"runCut1" : runCut1,
		"meadowFound" : meadowFound,
		"runCutMeadow" : runCutMeadow,
		"lakesFound" : lakesFound,
		"townFound" : townFound,
		"runCutTown" : runCutTown,
		"cityRoofFound" : cityRoofFound
	}


func from_dictionary(data):
	playerFaceColor = Color(data.playerFaceColor)
	time_score = data.time_score
	time = data.time
	beachFound = data.beachFound
	runCut1 = data.runCut1
	meadowFound = data.meadowFound
	runCutMeadow = data.runCutMeadow
	lakesFound = data.lakesFound
	townFound = data.townFound
	runCutTown = data.runCutTown
	cityRoofFound = data.cityRoofFound


func save():
	var data = {
		"globals" : to_dictionary(),
	}
	var file = FileAccess.open("user://savegame.json", FileAccess.WRITE)
	var json = JSON.stringify(data)
	file.store_line(json)
	file.close()


func loadGame():
	if FileAccess.file_exists("user://savegame.json"):
		var file = FileAccess.open("user://savegame.json", FileAccess.READ)
		var test_json_conv = JSON.new()
		test_json_conv.parse(file.get_as_text())
		var data = test_json_conv.get_data()
		file.close()
		from_dictionary(data.globals)
